@@ -10,7 +10,7 @@ use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
 use switchboard_protos::protos::fulfillment_manager::FulfillmentManagerState;
 use switchboard_protos::protos::fulfillment_manager::mod_FulfillmentManagerState;
 use switchboard_protos::protos::switchboard_account_types::SwitchboardAccountType;
-use zerocopy::{AsBytes, FromBytes, LayoutVerified};
+use zerocopy::{AsBytes, FromBytes};
 
 pub type PubkeyBuffer = [u8; 32];
 
@@ -33,38 +33,13 @@ pub struct FastRoundResultAccountData {
     pub result: FastRoundResult,
 }
 
-// REQUIRES THE ENTIRE BUFFER, WITH TYPE BYTE
-pub fn fast_from_bytes(bytes: &[u8]) -> Result<FastRoundResultAccountData, ProgramError> {
-    let mut res = FastRoundResultAccountData {
-        ..Default::default()
-    };
-    let mut buf = res.as_bytes_mut();
-    buf.copy_from_slice(&bytes[..buf.len()]);
-    // let len = std::mem::size_of::<T>();
-    // let buf: Vec<u8> = bytes[..len].to_vec().clone();
-    // let (res, _) = LayoutVerified::<&[u8], T>::new_from_prefix(&buf)
-        // .ok_or(ProgramError::InvalidAccountData)?;
-    return Ok(res);
+pub fn fast_parse_switchboard_result(bytes: &[u8]) -> FastRoundResultAccountData {
+    let mut res = FastRoundResultAccountData {..Default::default()};
+    let buf = res.as_bytes_mut();
+    buf.copy_from_slice(&bytes[1..buf.len()+1]);
+    return res;
 }
 
-// pub fn borsh_safe_serialize<T: BorshSerialize>(state: &T, type_indicator: SwitchboardAccountType) -> Vec<u8> {
-    // msg!("borsh serialize");
-    // let mut bytes = state.try_to_vec().unwrap();
-    // let size: usize = bytes.len();
-    // let mut res = vec![type_indicator as u8];
-    // res.append(&mut size.to_le_bytes().to_vec());
-    // res.append(&mut bytes);
-    // return res;
-// }
-//
-// pub fn borsh_safe_deserialize<T: BorshDeserialize>(bytes: &[u8]) -> Result<T, ProgramError> {
-    // let size_buf: &[u8] = &bytes[1..9];
-    // let size = usize::from_le_bytes(size_buf.try_into().unwrap());
-    // let buf = &bytes[9..size + 9];
-    // let res = &buf[..size].to_vec();
-    // T::try_from_slice(res).map_err(|_| ProgramError::InvalidAccountData)
-// }
-
 pub fn save_state<T: MessageWrite>(
     account: &AccountInfo,
     state: &T,
